Personal events
===============

.. _core-personal-event:

AlekSIS' calendar system allows users to create *personal events* for any purpose.
This can be done via the ``+`` button on the bottom right of the calendar overview
page.

.. image:: ../_static/create_personal_event.png
  :width: 100%
  :alt: Personal event creation dialog

Personal events must contain a start and end date or datetime as well as a title.
Besides that, they can store the following data:

- **Rule for repetition**: In case you want your event to be recurring, click on the
    ``One-time`` button. Two fields will be shown that allow you to specify the repetition
    frequency and, optionally, an end date.
- **Description**
- **Location**
- **Participating people**: By default, personal events are only visible to yourself. In
    case you want other persons to see your event in their own calendars, you can select
    them here.
- **Participating groups**: All members of the groups selected here will be able to see
    your personal event in their own calendars.

You can edit or delete a personal event you created yourself by clicking on any instance
of said event in the calendar overview page and then clicking the respective buttons in
the dialog that then appears.
